@@ -21,7 +21,6 @@
 from gi.repository import Gtk
 
 from gwakeonlan.constants import APP_ID
-
 from gwakeonlan.ui.main import UIMain
 
 
@@ -30,13 +29,17 @@ class Application(Gtk.Application):
         """Prepare the GtkApplication"""
         super(self.__class__, self).__init__(application_id=APP_ID)
         self.options = options
-        self.connect("activate", self.activate)
+        self.ui = None
+        self.connect('activate', self.activate)
         self.connect('startup', self.startup)
 
+    # noinspection PyUnusedLocal
     def startup(self, application):
         """Configure the application during the startup"""
-        self.ui = UIMain(self, self.options)
+        self.ui = UIMain(application=self,
+                         options=self.options)
 
+    # noinspection PyMethodOverriding
     def activate(self, application):
         """Execute the application"""
         self.ui.run()
