@@ -18,7 +18,6 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ##
 
-from gettext import gettext, dgettext
 import itertools
 import logging
 import pathlib
@@ -30,12 +29,10 @@ from gi.repository import GdkPixbuf
 
 from gwakeonlan.constants import DIR_UI
 
-localized_messages = {}
-
 
 def format_mac_address(mac):
     """Return the mac address formatted with colon"""
-    mac = mac.replace(':', '').replace('.', '')
+    mac = mac.replace(':', '').replace('.', '').replace('-', '')
     return ':'.join([mac[i:i+2] for i in range(0, len(mac), 2)]).upper()
 
 
@@ -59,7 +56,7 @@ def get_pixbuf_from_icon_name(icon_name, size):
     else:
         # The icon was not found in the current theme, search for filenames
         # with png or jpg extensions
-        if (path_icon_name.suffix.lower() in ('.png', '.jpg', '.xpm', '.svg')):
+        if path_icon_name.suffix.lower() in ('.png', '.jpg', '.xpm', '.svg'):
             filenames = (icon_name, )
         else:
             filenames = (f'{icon_name}.png',
@@ -130,30 +127,11 @@ def show_message_dialog_yesno(parent, message, title, default_response):
     return response
 
 
-def text(message, gtk30=False, context=None):
-    """Return a translated message and cache it for reuse"""
-    if message not in localized_messages:
-        if gtk30:
-            # Get a message translated from GTK+ 3 domain
-            full_message = message if not context else f'{context}\04{message}'
-            localized_messages[message] = dgettext('gtk30', full_message)
-            # Fix for untranslated messages with context
-            if context and localized_messages[message] == full_message:
-                localized_messages[message] = dgettext('gtk30', message)
-        else:
-            localized_messages[message] = gettext(message)
-    return localized_messages[message]
-
-
-def text_gtk30(message, context=None):
-    """Return a translated text from GTK+ 3.0"""
-    return text(message=message, gtk30=True, context=context)
-
-
 def wake_on_lan(mac_address, port_number, destination):
-    """Turn on remote machine using Wake On LAN."""
-    logging.info('turning on: %s through %s using port number %d' % (
-        mac_address, destination, port_number))
+    """Turn on remote machine using Wake On LAN"""
+    logging.info(f'turning on: {mac_address} '
+                 f'through {destination} '
+                 f'using port number {port_number}')
     # Magic packet (6 times FF + 16 times MAC address)
     packet = 'FF' * 6 + mac_address.replace(':', '') * 16
     data = []
@@ -161,8 +139,7 @@ def wake_on_lan(mac_address, port_number, destination):
         data.append(struct.pack('B', int(packet[i:i+2], 16)))
 
     # Send magic packet to the destination
-    logging.info('sending packet %s [%d/%d]\n' % (
-        packet, len(packet), len(data)))
+    logging.info(f'sending packet {packet} [{len(packet)}/{len(data)}]\n')
     sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
     if destination == '255.255.255.255':
@@ -170,8 +147,3 @@ def wake_on_lan(mac_address, port_number, destination):
     data = b''.join(data)
     for _ in range(10):
         sock.sendto(data, (destination, port_number))
-
-
-# This special alias is used to track localization requests to catch
-# by xgettext. The text() calls aren't tracked by xgettext
-_ = text
